@@ -16,7 +16,7 @@
  *  License along with this library; if not, write to the Free
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Authors : Carlos Garca Campos <carlosgc@gnome.org>
+ * Authors : Carlos García Campos <carlosgc@gnome.org>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -94,15 +94,16 @@ static void     cpufreq_applet_update            (CPUFreqApplet      *applet,
                                                   CPUFreqMonitor     *monitor);
 static void     cpufreq_applet_refresh           (CPUFreqApplet      *applet);
 
-static void     cpufreq_applet_destroy           (GtkObject          *widget);
+static void     cpufreq_applet_dispose           (GObject          *widget);
 static gboolean cpufreq_applet_button_press      (GtkWidget          *widget,
                                                   GdkEventButton     *event);
 static gboolean cpufreq_applet_key_press         (GtkWidget          *widget,
                                                   GdkEventKey        *event);
 static void     cpufreq_applet_size_allocate     (GtkWidget          *widget,
                                                   GtkAllocation      *allocation);
-static void     cpufreq_applet_size_request      (GtkWidget          *widget,
-						  GtkRequisition     *requisition);
+static void   cpufreq_applet_get_preferred_width (GtkWidget          *widget,
+                                                  gint               *minimum_width,
+                                                  gint               *natural_width);
 static void     cpufreq_applet_change_orient     (PanelApplet        *pa,
                                                   PanelAppletOrient   orient);
 static gboolean cpufreq_applet_factory           (CPUFreqApplet      *applet,
@@ -213,13 +214,13 @@ static void
 cpufreq_applet_class_init (CPUFreqAppletClass *klass)
 {
         PanelAppletClass *applet_class = PANEL_APPLET_CLASS (klass);
-        GtkObjectClass   *gtkobject_class = GTK_OBJECT_CLASS (klass);
+        GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
         GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
 
-        gtkobject_class->destroy = cpufreq_applet_destroy;
+        gobject_class->dispose = cpufreq_applet_dispose;
            
         widget_class->size_allocate = cpufreq_applet_size_allocate;
-	widget_class->size_request = cpufreq_applet_size_request;
+	widget_class->get_preferred_width = cpufreq_applet_get_preferred_width;
         widget_class->button_press_event = cpufreq_applet_button_press;
         widget_class->key_press_event = cpufreq_applet_key_press;
            
@@ -227,7 +228,7 @@ cpufreq_applet_class_init (CPUFreqAppletClass *klass)
 }
 
 static void
-cpufreq_applet_destroy (GtkObject *widget)
+cpufreq_applet_dispose (GObject *widget)
 {
         CPUFreqApplet *applet;
         gint           i;
@@ -256,7 +257,7 @@ cpufreq_applet_destroy (GtkObject *widget)
                 applet->popup = NULL;
         }
 
-        GTK_OBJECT_CLASS (cpufreq_applet_parent_class)->destroy (widget);
+        G_OBJECT_CLASS (cpufreq_applet_parent_class)->dispose (widget);
 }
 
 static void
@@ -301,7 +302,7 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 	available_freqs = cpufreq_monitor_get_available_frequencies (applet->monitor);
 	while (available_freqs) {
 		GtkWidget     *label;
-		GtkRequisition req;
+                gint           label_width;
 		const gchar   *text;
 		gchar         *freq_text;
 		gint           freq;
@@ -311,9 +312,9 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 
 		freq_text = cpufreq_utils_get_frequency_label (freq);
 		label = gtk_label_new (freq_text);
-		gtk_widget_size_request (label, &req);
+                gtk_widget_get_preferred_width (label, &label_width, NULL);
 
-		width = MAX (width, req.width);
+		width = MAX (width, label_width);
 
 		g_free (freq_text);
 		gtk_widget_destroy (label);
@@ -329,15 +330,15 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 static gint
 cpufreq_applet_get_max_perc_width (CPUFreqApplet *applet)
 {
-	GtkWidget      *label;
-	GtkRequisition req;
-	
+	GtkWidget *label;
+        gint       width;
+
 	if (applet->max_perc_width > 0)
 		return applet->max_perc_width;
 
 	label = gtk_label_new ("100%");
-	gtk_widget_size_request (label, &req);
-	applet->max_perc_width = req.width;
+        gtk_widget_get_preferred_width (label, &width, NULL);
+	applet->max_perc_width = width;
 	gtk_widget_destroy (label);
 
 	return applet->max_perc_width;
@@ -347,20 +348,17 @@ static gint
 cpufreq_applet_get_max_unit_width (CPUFreqApplet *applet)
 {
 	GtkWidget     *label;
-	GtkRequisition req;
 	gint           w1, w2;
-	
+
 	if (applet->max_unit_width > 0)
 		return applet->max_unit_width;
 
 	label = gtk_label_new ("GHz");
-	gtk_widget_size_request (label, &req);
-	w1 = req.width;
+        gtk_widget_get_preferred_width (label, &w1, NULL);
 
 	gtk_label_set_text (GTK_LABEL (label), "MHz");
-	gtk_widget_size_request (label, &req);
-	w2 = req.width;
-	
+        gtk_widget_get_preferred_width (label, &w2, NULL);
+
 	gtk_widget_destroy (label);
 
 	applet->max_unit_width = MAX (w1, w2);
@@ -369,21 +367,21 @@ cpufreq_applet_get_max_unit_width (CPUFreqApplet *applet)
 }
 
 static void
-cpufreq_applet_size_request (GtkWidget *widget, GtkRequisition *requisition)
+cpufreq_applet_get_preferred_width (GtkWidget *widget,
+                                    gint      *minimum_width,
+                                    gint      *natural_width)
 {
-	CPUFreqApplet *applet;
-	gint           labels_width = 0;
-	gint           width;
+        CPUFreqApplet *applet;
+        gint           labels_width = 0;
+        gint           width;
 
-	applet = CPUFREQ_APPLET (widget);
+        applet = CPUFREQ_APPLET (widget);
 
-	GTK_WIDGET_CLASS (cpufreq_applet_parent_class)->size_request (widget, requisition);
+        if (applet->orient == PANEL_APPLET_ORIENT_LEFT ||
+            applet->orient == PANEL_APPLET_ORIENT_RIGHT)
+                return;
 
-	if (applet->orient == PANEL_APPLET_ORIENT_LEFT ||
-	    applet->orient == PANEL_APPLET_ORIENT_RIGHT)
-		return;
-
-	if (applet->show_freq) {
+        if (applet->show_freq) {
 		labels_width += cpufreq_applet_get_max_label_width (applet) + 2;
 	}
 
@@ -396,17 +394,17 @@ cpufreq_applet_size_request (GtkWidget *widget, GtkRequisition *requisition)
 	}
 
 	if (applet->show_icon) {
-		GtkRequisition req;
+		gint icon_width;
 
-		gtk_widget_size_request (applet->icon, &req);
+                gtk_widget_get_preferred_width (applet->icon, &icon_width, NULL);
 		width = GTK_IS_HBOX (applet->box) ?
-			labels_width + req.width + 2 :
-			MAX (labels_width, req.width + 2);
+			labels_width + icon_width + 2 :
+			MAX (labels_width, icon_width + 2);
 	} else {
 		width = labels_width;
 	}
 
-	requisition->width = width;
+        *minimum_width = *natural_width = width;
 }
 
 static void
@@ -424,7 +422,7 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
 
         widget = GTK_WIDGET (gdata);
 
-        gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+        gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
 
         gdk_window_get_origin (gtk_widget_get_window (widget), &menu_xpos, &menu_ypos);
 
@@ -512,12 +510,12 @@ cpufreq_applet_key_press (GtkWidget *widget, GdkEventKey *event)
         applet = CPUFREQ_APPLET (widget);
 
         switch (event->keyval) {
-        case GDK_KP_Enter:
-        case GDK_ISO_Enter:
-        case GDK_3270_Enter:
-        case GDK_Return:
-        case GDK_space:
-        case GDK_KP_Space:
+        case GDK_KEY_KP_Enter:
+        case GDK_KEY_ISO_Enter:
+        case GDK_KEY_3270_Enter:
+        case GDK_KEY_Return:
+        case GDK_KEY_space:
+        case GDK_KEY_KP_Space:
                 cpufreq_applet_menu_popup (applet, event->time);
 
                 return TRUE;
@@ -741,7 +739,7 @@ cpufreq_applet_update_visibility (CPUFreqApplet *applet)
 static void
 cpufreq_applet_update (CPUFreqApplet *applet, CPUFreqMonitor *monitor)
 {
-        gchar       *text_tip, *text_mode = NULL;
+        gchar       *text_mode = NULL;
         gchar       *freq_label, *unit_label;
         gint         freq;
         gint         perc;
@@ -819,7 +817,7 @@ cpufreq_applet_get_widget_size (CPUFreqApplet *applet,
         if (!gtk_widget_get_visible (widget))
                 return 0;
 	
-        gtk_widget_size_request (widget, &req);
+        gtk_widget_get_preferred_size (widget, &req, NULL);
         
         switch (applet->orient) {
         case PANEL_APPLET_ORIENT_LEFT:
@@ -1027,6 +1025,5 @@ cpufreq_applet_factory (CPUFreqApplet *applet, const gchar *iid, gpointer gdata)
 
 PANEL_APPLET_OUT_PROCESS_FACTORY ("CPUFreqAppletFactory",
 				  CPUFREQ_TYPE_APPLET,
-				  "cpufreq-applet",
 				  (PanelAppletFactoryCallback) cpufreq_applet_factory,
 				  NULL)
